==> plantuml-1.2022.2.tar.gz: plantuml-1.2022.2/test/nonreg/simple/A0006_TestResult.java <==
package nonreg.simple;

public class A0006_TestResult {
}
/*
"""
DPI: 96
dimension: [ 149.3989 ; 225.0000 ]
scaleFactor: 1.0000
seed: -2375783792654745998
svgLinkTarget: _top
hoverPathColorRGB: null
preserveAspectRatio: none

EMPTY:
  pt1: [ 31.3586 ; 16.0000 ]
  pt2: [ 112.0403 ; 51.0000 ]

RECTANGLE:
  pt1: [ 36.3586 ; 21.0000 ]
  pt2: [ 106.0403 ; 45.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: 0
  backcolor: ffffff00

TEXT:
  text: title
  position: [ 41.3586 ; 36.8889 ]
  orientation: 0
  font: SansSerif.bold/14 [BOLD]
  color: ff000000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 13.3206 ; 186.0000 ]
  pt2: [ 130.0783 ; 203.0000 ]

RECTANGLE:
  pt1: [ 14.3206 ; 187.0000 ]
  pt2: [ 128.0783 ; 201.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: 0
  backcolor: ff800080

TEXT:
  text: caption
  position: [ 14.3206 ; 197.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

LINE:
  pt1: [ 41.0000 ; 80.0000 ]
  pt2: [ 41.0000 ; 114.0000 ]
  stroke: 5.0-5.0-0.5
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 112.6938 ; 80.0000 ]
  pt2: [ 112.6938 ; 114.0000 ]
  stroke: 5.0-5.0-0.5
  shadow: 0
  color: ff181818

RECTANGLE:
  pt1: [ 5.0000 ; 51.0000 ]
  pt2: [ 78.6938 ; 79.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Sally
  position: [ 12.0000 ; 68.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 5.0000 ; 113.0000 ]
  pt2: [ 78.6938 ; 141.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Sally
  position: [ 12.0000 ; 130.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 88.6938 ; 51.0000 ]
  pt2: [ 138.3989 ; 79.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Bob
  position: [ 95.6938 ; 68.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 88.6938 ; 113.0000 ]
  pt2: [ 138.3989 ; 141.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Bob
  position: [ 95.6938 ; 130.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

POLYGON:
  points:
   - [ 101.5463 ; 92.0000 ]
   - [ 111.5463 ; 96.0000 ]
   - [ 101.5463 ; 100.0000 ]
   - [ 105.5463 ; 96.0000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818
  backcolor: ff181818

LINE:
  pt1: [ 41.8469 ; 96.0000 ]
  pt2: [ 107.5463 ; 96.0000 ]
  stroke: 2.0-2.0-1.0
  shadow: 0
  color: ff181818

EMPTY:
  pt1: [ 65.0665 ; 5.0000 ]
  pt2: [ 143.3989 ; 16.0000 ]

RECTANGLE:
  pt1: [ 65.0665 ; 5.0000 ]
  pt2: [ 142.3989 ; 15.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: 0
  backcolor: ffff0000

TEXT:
  text: header
  position: [ 65.0665 ; 12.7778 ]
  orientation: 0
  font: SansSerif.plain/10 []
  color: ff888888
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 27.6323 ; 203.0000 ]
  pt2: [ 115.7666 ; 219.0000 ]

RECTANGLE:
  pt1: [ 27.6323 ; 203.0000 ]
  pt2: [ 114.7666 ; 218.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: 0
  backcolor: ff0000ff

TEXT:
  text: footer
  position: [ 27.6323 ; 214.6667 ]
  orientation: 0
  font: SansSerif.plain/15 []
  color: ffff0000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 10.6527 ; 143.0000 ]
  pt2: [ 132.7462 ; 186.0000 ]

RECTANGLE:
  pt1: [ 18.6527 ; 151.0000 ]
  pt2: [ 123.7462 ; 177.0000 ]
  xCorner: 15
  yCorner: 15
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff000000
  backcolor: ff008000

TEXT:
  text: legend
  position: [ 24.6527 ; 167.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

"""
*/

==> plantuml-1.2022.10.tar.gz: plantuml-1.2022.10/test/nonreg/simple/A0006_TestResult.java <==
package nonreg.simple;

public class A0006_TestResult {
}
/*
"""
DPI: 96
dimension: [ 149.3989 ; 225.0000 ]
scaleFactor: 1.0000
seed: -2375783792654745998
svgLinkTarget: _top
hoverPathColorRGB: null
preserveAspectRatio: none

EMPTY:
  pt1: [ 31.3586 ; 16.0000 ]
  pt2: [ 112.0403 ; 51.0000 ]

RECTANGLE:
  pt1: [ 36.3586 ; 21.0000 ]
  pt2: [ 106.0403 ; 45.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: NULL_COLOR
  backcolor: ffffff00

TEXT:
  text: title
  position: [ 41.3586 ; 36.8889 ]
  orientation: 0
  font: SansSerif.bold/14 [BOLD]
  color: ff000000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 13.3206 ; 186.0000 ]
  pt2: [ 130.0783 ; 203.0000 ]

RECTANGLE:
  pt1: [ 14.3206 ; 187.0000 ]
  pt2: [ 128.0783 ; 201.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: NULL_COLOR
  backcolor: ff800080

TEXT:
  text: caption
  position: [ 14.3206 ; 197.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

LINE:
  pt1: [ 41.0000 ; 80.0000 ]
  pt2: [ 41.0000 ; 114.0000 ]
  stroke: 5.0-5.0-0.5
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 112.6938 ; 80.0000 ]
  pt2: [ 112.6938 ; 114.0000 ]
  stroke: 5.0-5.0-0.5
  shadow: 0
  color: ff181818

RECTANGLE:
  pt1: [ 5.0000 ; 51.0000 ]
  pt2: [ 78.6938 ; 79.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Sally
  position: [ 12.0000 ; 68.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 5.0000 ; 113.0000 ]
  pt2: [ 78.6938 ; 141.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Sally
  position: [ 12.0000 ; 130.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 88.6938 ; 51.0000 ]
  pt2: [ 138.3989 ; 79.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Bob
  position: [ 95.6938 ; 68.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 88.6938 ; 113.0000 ]
  pt2: [ 138.3989 ; 141.0000 ]
  xCorner: 5
  yCorner: 5
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: ffe2e2f0

TEXT:
  text: Bob
  position: [ 95.6938 ; 130.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

POLYGON:
  points:
   - [ 101.5463 ; 92.0000 ]
   - [ 111.5463 ; 96.0000 ]
   - [ 101.5463 ; 100.0000 ]
   - [ 105.5463 ; 96.0000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818
  backcolor: ff181818

LINE:
  pt1: [ 41.8469 ; 96.0000 ]
  pt2: [ 107.5463 ; 96.0000 ]
  stroke: 2.0-2.0-1.0
  shadow: 0
  color: ff181818

EMPTY:
  pt1: [ 65.0665 ; 5.0000 ]
  pt2: [ 143.3989 ; 16.0000 ]

RECTANGLE:
  pt1: [ 65.0665 ; 5.0000 ]
  pt2: [ 142.3989 ; 15.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: NULL_COLOR
  backcolor: ffff0000

TEXT:
  text: header
  position: [ 65.0665 ; 12.7778 ]
  orientation: 0
  font: SansSerif.plain/10 []
  color: ff888888
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 27.6323 ; 203.0000 ]
  pt2: [ 115.7666 ; 219.0000 ]

RECTANGLE:
  pt1: [ 27.6323 ; 203.0000 ]
  pt2: [ 114.7666 ; 218.0000 ]
  xCorner: 0
  yCorner: 0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: NULL_COLOR
  backcolor: ff0000ff

TEXT:
  text: footer
  position: [ 27.6323 ; 214.6667 ]
  orientation: 0
  font: SansSerif.plain/15 []
  color: ffff0000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 10.6527 ; 143.0000 ]
  pt2: [ 132.7462 ; 186.0000 ]

RECTANGLE:
  pt1: [ 18.6527 ; 151.0000 ]
  pt2: [ 123.7462 ; 177.0000 ]
  xCorner: 15
  yCorner: 15
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff000000
  backcolor: ff008000

TEXT:
  text: legend
  position: [ 24.6527 ; 167.8889 ]
  orientation: 0
  font: SansSerif.plain/14 []
  color: ff000000
  extendedColor: NULL_COLOR

"""
*/
